summaryrefslogtreecommitdiffstats
path: root/src/interface/smbios
diff options
context:
space:
mode:
authorMichael Brown2013-07-18 14:35:19 +0200
committerMichael Brown2013-07-18 16:50:02 +0200
commit063645118ce1f73e143bb17a74bd678d31d7563e (patch)
treed8333d35499f3cf62321595400bc49e8b27cdf2c /src/interface/smbios
parent[build] Fix %.licence build target (diff)
downloadipxe-063645118ce1f73e143bb17a74bd678d31d7563e.tar.gz
ipxe-063645118ce1f73e143bb17a74bd678d31d7563e.tar.xz
ipxe-063645118ce1f73e143bb17a74bd678d31d7563e.zip
[settings] Clarify usage of the term "named setting"
There are currently two conflicting usages of the term "named setting" within iPXE: one refers to predefined settings (such as show up in the "config" UI), the other refers to settings identified by a name (such as "net0.dhcp/ip"). Split these usages into the term "predefined setting" and "named setting" to avoid ambiguity. Signed-off-by: Michael Brown <mcb30@ipxe.org>
Diffstat (limited to 'src/interface/smbios')
-rw-r--r--src/interface/smbios/smbios_settings.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/interface/smbios/smbios_settings.c b/src/interface/smbios/smbios_settings.c
index d2975df4..ecd3f1d9 100644
--- a/src/interface/smbios/smbios_settings.c
+++ b/src/interface/smbios/smbios_settings.c
@@ -197,8 +197,8 @@ struct setting uuid_setting __setting ( SETTING_HOST ) = {
.scope = &smbios_settings_scope,
};
-/** Other SMBIOS named settings */
-struct setting smbios_named_settings[] __setting ( SETTING_HOST_EXTRA ) = {
+/** Other SMBIOS predefined settings */
+struct setting smbios_predefined_settings[] __setting ( SETTING_HOST_EXTRA ) = {
{
.name = "manufacturer",
.description = "Manufacturer",